Index: libspeex/bits.c
===================================================================
--- libspeex/bits.c	(revision 9770)
+++ libspeex/bits.c	(working copy)
@@ -40,15 +40,17 @@
 #include "misc.h"
 
 /** Maximum size of the bit-stream (for fixed-size allocation) */
-#define MAX_BYTES_PER_FRAME (2000/BYTES_PER_CHAR)
+#ifndef MAX_CHARS_PER_FRAME
+#define MAX_CHARS_PER_FRAME (2000/BYTES_PER_CHAR)
+#endif
 
 void speex_bits_init(SpeexBits *bits)
 {
-   bits->chars = (char*)speex_alloc(MAX_BYTES_PER_FRAME);
+   bits->chars = (char*)speex_alloc(MAX_CHARS_PER_FRAME);
    if (!bits->chars)
       return;
 
-   bits->buf_size = MAX_BYTES_PER_FRAME;
+   bits->buf_size = MAX_CHARS_PER_FRAME;
 
    bits->owner=1;
 
Index: libspeex/arch.h
===================================================================
--- libspeex/arch.h	(revision 9770)
+++ libspeex/arch.h	(working copy)
@@ -48,6 +48,8 @@
 typedef spx_int32_t   spx_word32_t;
 #ifdef _MSC_VER
 typedef __int64      spx_word64_t;
+#elif defined NO_LONGLONG
+typedef double    spx_word64_t;
 #else
 typedef long long    spx_word64_t;
 #endif
Index: libspeex/misc.c
===================================================================
--- libspeex/misc.c	(revision 9770)
+++ libspeex/misc.c	(working copy)
@@ -43,6 +43,10 @@
 #include "misc_bfin.h"
 #endif
 
+#ifdef USER_MISC
+#include "../src/user_misc.h"
+#endif
+
 #ifndef RELEASE
 void print_vec(float *vec, int len, char *name)
 {
@@ -127,28 +131,41 @@
 }
 #endif
 
+#ifndef OVERRIDE_SPEEX_ALLOC
 void *speex_alloc (int size)
 {
    return calloc(size,1);
 }
+#endif
+
+#ifndef OVERRIDE_SPEEX_ALLOC_SCRATCH
 void *speex_alloc_scratch (int size)
 {
    return calloc(size,1);
 }
+#endif
 
+#ifndef OVERRIDE_SPEEX_REALLOC
 void *speex_realloc (void *ptr, int size)
 {
    return realloc(ptr, size);
 }
+#endif
 
+#ifndef OVERRIDE_SPEEX_FREE
 void speex_free (void *ptr)
 {
    free(ptr);
 }
+#endif
+
+#ifndef OVERRIDE_SPEEX_FREE_SCRATCH
 void speex_free_scratch (void *ptr)
 {
    free(ptr);
 }
+#endif
+//#endif    /* !MANUAL_ALLOC */
 
 #ifndef OVERRIDE_SPEEX_MOVE
 void *speex_move (void *dest, void *src, int n)
@@ -157,21 +174,27 @@
 }
 #endif
 
+#ifndef OVERRIDE_SPEEX_ERROR
 void speex_error(const char *str)
 {
    fprintf (stderr, "Fatal error: %s\n", str);
    exit(1);
 }
+#endif
 
+#ifndef OVERRIDE_SPEEX_WARNING
 void speex_warning(const char *str)
 {
    fprintf (stderr, "warning: %s\n", str);
 }
+#endif
 
+#ifndef OVERRIDE_SPEEX_WARNING_INT
 void speex_warning_int(const char *str, int val)
 {
    fprintf (stderr, "warning: %s %d\n", str, val);
 }
+#endif
 
 #ifdef FIXED_POINT
 spx_word32_t speex_rand(spx_word16_t std, spx_int32_t *seed)
@@ -205,8 +228,11 @@
    return 3*std*((((float)rand())/RAND_MAX)-.5);
 }*/
 
+#ifndef OVERRIDE_SPEEX_PUTC
 void _speex_putc(int ch, void *file)
 {
    FILE *f = (FILE *)file;
    fprintf(f, "%c", ch);
 }
+#endif
+
